@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="el">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
 <context>
     <name>MainWindow</name>
     <message>
@@ -8,82 +6,129 @@
         <translation type="vanished">MX Οθόνη υποδοχής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="74"/>
+        <location filename="../mainwindow.ui" line="33"/>
         <source>&amp;Copy for forum</source>
         <translation>Αντιγραφή για το &amp;φόρουμ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="43"/>
+        <location filename="../mainwindow.ui" line="47"/>
         <source>Save the displayed system information to a text file.</source>
         <translation>Αποθήκευση των εμφανιζόμενων πληροφοριών σε αρχείο κειμένου.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="46"/>
-        <location filename="../mainwindow.cpp" line="91"/>
+        <location filename="../mainwindow.ui" line="50"/>
+        <location filename="../mainwindow.cpp" line="92"/>
         <source>Save text...</source>
         <translation>Αποθήκευση σε κείμενο...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="71"/>
+        <location filename="../mainwindow.ui" line="30"/>
         <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
-        <translation>Αποθήκευση των εμφανιζόμενων πληροφοριών στο πρόχειρο, έτοιμες για ανάρτηση στο φόρουμ (μέσα σε [CODE][/CODE]).</translation>
+        <translation>Αποθήκευση των εμφανιζόμενων πληροφοριών στο πρόχειρο, έτοιμες για ανάρτηση στο φόρουμ και μέσα σε [CODE][/CODE].</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="57"/>
+        <location filename="../mainwindow.ui" line="199"/>
         <source>Save the system information selected from the list to an archive file.</source>
         <translation>Αποθήκευση των επιλεγμένων σε συμπιεσμένο αρχείο.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="60"/>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.ui" line="202"/>
+        <location filename="../mainwindow.cpp" line="137"/>
         <source>&amp;Save...</source>
         <translation>&amp;Αποθήκευση...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="129"/>
+        <location filename="../mainwindow.ui" line="102"/>
         <source>Quit application</source>
         <translation>Κλείσιμο εφαρμογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="132"/>
+        <location filename="../mainwindow.ui" line="105"/>
         <source>Close</source>
         <translation>Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="139"/>
+        <location filename="../mainwindow.ui" line="112"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="181"/>
+        <location filename="../mainwindow.ui" line="154"/>
         <source>About this application</source>
         <translation>Περί της εφαρμογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="184"/>
+        <location filename="../mainwindow.ui" line="157"/>
         <source>About...</source>
         <translation>Περί...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="191"/>
+        <location filename="../mainwindow.ui" line="164"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="115"/>
+        <location filename="../mainwindow.ui" line="254"/>
+        <source>Journald</source>
+        <extracomment>systemd journalctl tab</extracomment>
+        <translation>Journald</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="262"/>
+        <source>Log Type</source>
+        <extracomment>type of log, either user level or system</extracomment>
+        <translation>Τύπος αρχείου καταγραφής</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="270"/>
+        <source>System</source>
+        <extracomment>system level log</extracomment>
+        <translation>Σύστημα</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="275"/>
+        <source>User</source>
+        <extracomment>user level log</extracomment>
+        <translation>Χρήστης</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="283"/>
+        <source>Priority Level</source>
+        <extracomment>level of status message to view</extracomment>
+        <translation>Επίπεδο προτεραιότητας</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="334"/>
+        <source>Choose Boot Log</source>
+        <extracomment>choose a boot to view the log</extracomment>
+        <translation>Επιλογή αρχείου καταγραφής εκκίνησης</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="341"/>
+        <source>Service Search</source>
+        <extracomment>seek and ye shall find</extracomment>
+        <translation>Αναζήτηση υπηρεσίας</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="351"/>
+        <source>...</source>
+        <translation>...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="88"/>
         <source>Help</source>
         <translation>Βοήθεια</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="187"/>
+        <location filename="../mainwindow.cpp" line="199"/>
         <source>Version: </source>
         <translation>Έκδοση: </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="187"/>
-        <location filename="../mainwindow.cpp" line="325"/>
-        <location filename="../mainwindow.cpp" line="354"/>
+        <location filename="../mainwindow.cpp" line="199"/>
+        <location filename="../mainwindow.cpp" line="344"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Quick System Info</source>
         <translation>Συνοπτικές πληροφορίες συστήματος</translation>
     </message>
@@ -93,38 +138,38 @@
         <translation>Φόρτωση...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="191"/>
+        <location filename="../mainwindow.cpp" line="203"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="186"/>
+        <location filename="../mainwindow.cpp" line="198"/>
         <source>About Quick-System-Info-gui</source>
         <translation>Περί του Συνοπτικές πληροφορίες συστήματος σε γραφικό περιβάλλον</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="95"/>
+        <location filename="../mainwindow.cpp" line="96"/>
         <source>&amp;Find...</source>
         <translation>&amp;Εύρεση...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="99"/>
-        <location filename="../mainwindow.cpp" line="481"/>
+        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="510"/>
         <source>Find &amp;Next</source>
         <translation>Εύρεση ε&amp;πόμενου</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="115"/>
+        <location filename="../mainwindow.cpp" line="126"/>
         <source>Select &amp;All</source>
         <translation>Επιλογή ό&amp;λων</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="121"/>
+        <location filename="../mainwindow.cpp" line="132"/>
         <source>Revert Selection</source>
         <translation>Αντιστροφή επιλογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="188"/>
+        <location filename="../mainwindow.cpp" line="200"/>
         <source>Program for displaying a quick system info report</source>
         <translation>Πρόγραμμα για την εμφάνιση συνοπτικών πληροφοριών του συστήματος</translation>
     </message>
@@ -133,71 +178,84 @@
         <translation type="vanished">Άδεια</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="193"/>
+        <location filename="../mainwindow.cpp" line="205"/>
         <source>%1 License</source>
-        <translation type="unfinished"></translation>
+        <translation>Άδεια %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="280"/>
+        <location filename="../mainwindow.cpp" line="299"/>
         <source>Open folder</source>
         <translation>Άνοιγμα φακέλου</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="282"/>
+        <location filename="../mainwindow.cpp" line="301"/>
         <source>OK</source>
         <translation>Εντάξει</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="440"/>
+        <location filename="../mainwindow.cpp" line="468"/>
         <source>&amp;Save (×%1)...</source>
         <translation>Απο&amp;θήκευση (×%1)...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="474"/>
+        <location filename="../mainwindow.cpp" line="503"/>
         <source>Find</source>
         <translation>Εύρεση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="477"/>
+        <location filename="../mainwindow.cpp" line="506"/>
         <source>&amp;Find what:</source>
         <translation>Εύ&amp;ρεση του:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="487"/>
+        <location filename="../mainwindow.cpp" line="516"/>
         <source>Match c&amp;ase</source>
         <translation>Ταίριασμα &amp;πεζών-κεφαλαίων</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="488"/>
+        <location filename="../mainwindow.cpp" line="517"/>
         <source>Match &amp;whole word only</source>
         <translation>Ταίριασμα &amp;ολόκληρων λέξεων</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="491"/>
+        <location filename="../mainwindow.cpp" line="520"/>
         <source>Direction</source>
         <translation>Κατεύθυνση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="493"/>
+        <location filename="../mainwindow.cpp" line="522"/>
         <source>&amp;Up</source>
         <translation>Ε&amp;πάνω</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="494"/>
+        <location filename="../mainwindow.cpp" line="523"/>
         <source>&amp;Down</source>
         <translation>&amp;Κάτω</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="536"/>
+        <location filename="../mainwindow.cpp" line="568"/>
+        <location filename="../mainwindow.cpp" line="573"/>
         <source>Cannot find &quot;%1&quot;</source>
         <translation>Δεν βρέθηκε &quot;%1&quot;</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="710"/>
+        <source>No journal entries found at this admin and priority level</source>
+        <comment>no journal entries found at the options specified</comment>
+        <translation>Δεν βρέθηκαν καταχωρήσεις με αυτό το επίπεδο προτεραιότητας και σε αυτόν τον διαχειριστή</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="712"/>
+        <source>Error running journalctl command</source>
+        <comment>error report for journalctl command</comment>
+        <translation>Σφάλμα κατά την εκτέλεση της εντολής journalctl</translation>
+    </message>
     <message>
         <source>Changelog</source>
         <translation type="vanished">Αρχείο αλλαγών</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="482"/>
+        <location filename="../mainwindow.cpp" line="511"/>
         <source>Cancel</source>
         <translation>Άκυρο</translation>
     </message>
@@ -206,41 +264,37 @@
         <translation type="vanished">&amp;Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="223"/>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>Save System Information</source>
         <translation>Αποθήκευση των πληροφοριών του συστήματος</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../mainwindow.cpp" line="298"/>
         <source>System information saved.</source>
         <translation>Οι πληροφορίες του συστήματος αποθηκεύτηκαν.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../mainwindow.cpp" line="306"/>
         <source>Could not save system information.</source>
         <translation>Οι πληροφορίες του συστήματος δεν αποθηκεύτηκαν.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="332"/>
+        <location filename="../mainwindow.cpp" line="351"/>
         <source>history</source>
         <translation>ιστορικό</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="354"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>%1 Help</source>
         <translation>Βοήθεια %1</translation>
     </message>
     <message>
-        <source>Quick System Info (gui)</source>
-        <translation type="vanished">Συνοπτικές πληροφορίες συστήματος (γραφικό περιβάλλον)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="81"/>
+        <location filename="../mainwindow.cpp" line="82"/>
         <source>Copy for forum</source>
         <translation>Αντιγραφή για το φόρουμ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="86"/>
+        <location filename="../mainwindow.cpp" line="87"/>
         <source>Plain text copy</source>
         <translation>Αντιγραφή σε μορφή κειμένου</translation>
     </message>
@@ -287,4 +341,4 @@
         <translation>&amp;Κλείσιμο</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
