@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sq">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
 <context>
     <name>MainWindow</name>
     <message>
@@ -8,82 +6,129 @@
         <translation type="vanished">Mirë se vini në MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="74"/>
+        <location filename="../mainwindow.ui" line="33"/>
         <source>&amp;Copy for forum</source>
         <translation>&amp;Kopjoji për forum</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="43"/>
+        <location filename="../mainwindow.ui" line="47"/>
         <source>Save the displayed system information to a text file.</source>
         <translation>Ruajini hollësitë e shfaqura të sistemit në një kartelë tekst.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="46"/>
-        <location filename="../mainwindow.cpp" line="91"/>
+        <location filename="../mainwindow.ui" line="50"/>
+        <location filename="../mainwindow.cpp" line="92"/>
         <source>Save text...</source>
         <translation>Ruajeni si tekst…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="71"/>
+        <location filename="../mainwindow.ui" line="30"/>
         <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
         <translation>Kopjojini në të papastër hollësitë e shfaqura të sistemit, paketuar brenda etiketash [CODE][/CODE], gati për t’i përdorur në ndonjë postim forumesh.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="57"/>
+        <location filename="../mainwindow.ui" line="199"/>
         <source>Save the system information selected from the list to an archive file.</source>
         <translation>Ruani në një kartelë arkiv hollësitë e sistemit të përzgjedhura prej listës.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="60"/>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.ui" line="202"/>
+        <location filename="../mainwindow.cpp" line="137"/>
         <source>&amp;Save...</source>
         <translation>&amp;Ruani…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="129"/>
+        <location filename="../mainwindow.ui" line="102"/>
         <source>Quit application</source>
         <translation>Mbylle aplikacionin</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="132"/>
+        <location filename="../mainwindow.ui" line="105"/>
         <source>Close</source>
         <translation>Mbylle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="139"/>
+        <location filename="../mainwindow.ui" line="112"/>
         <source>Alt+N</source>
         <translation>Alt+M</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="181"/>
+        <location filename="../mainwindow.ui" line="154"/>
         <source>About this application</source>
         <translation>Mbi këtë aplikacion</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="184"/>
+        <location filename="../mainwindow.ui" line="157"/>
         <source>About...</source>
         <translation>Mbi…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="191"/>
+        <location filename="../mainwindow.ui" line="164"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="115"/>
+        <location filename="../mainwindow.ui" line="254"/>
+        <source>Journald</source>
+        <extracomment>systemd journalctl tab</extracomment>
+        <translation>Journald</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="262"/>
+        <source>Log Type</source>
+        <extracomment>type of log, either user level or system</extracomment>
+        <translation>Lloj Regjistri</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="270"/>
+        <source>System</source>
+        <extracomment>system level log</extracomment>
+        <translation>Sistem</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="275"/>
+        <source>User</source>
+        <extracomment>user level log</extracomment>
+        <translation>Përdorues</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="283"/>
+        <source>Priority Level</source>
+        <extracomment>level of status message to view</extracomment>
+        <translation>Shkallë Përparësie</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="334"/>
+        <source>Choose Boot Log</source>
+        <extracomment>choose a boot to view the log</extracomment>
+        <translation>Zgjidhni Regjistër Nisjesh</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="341"/>
+        <source>Service Search</source>
+        <extracomment>seek and ye shall find</extracomment>
+        <translation>Kërkim Shërbimi</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="351"/>
+        <source>...</source>
+        <translation>…</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="88"/>
         <source>Help</source>
         <translation>Ndihmë</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="187"/>
+        <location filename="../mainwindow.cpp" line="199"/>
         <source>Version: </source>
         <translation>Version: </translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="187"/>
-        <location filename="../mainwindow.cpp" line="325"/>
-        <location filename="../mainwindow.cpp" line="354"/>
+        <location filename="../mainwindow.cpp" line="199"/>
+        <location filename="../mainwindow.cpp" line="344"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Quick System Info</source>
         <translation>Hollësi Sistemi Shpejt e Shpejt</translation>
     </message>
@@ -93,38 +138,38 @@
         <translation>Po ngarkohet…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="191"/>
+        <location filename="../mainwindow.cpp" line="203"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Të drejta kopjimi (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="186"/>
+        <location filename="../mainwindow.cpp" line="198"/>
         <source>About Quick-System-Info-gui</source>
         <translation>Mbi Quick-System-Info-gui</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="95"/>
+        <location filename="../mainwindow.cpp" line="96"/>
         <source>&amp;Find...</source>
         <translation>&amp;Gjeni…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="99"/>
-        <location filename="../mainwindow.cpp" line="481"/>
+        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="510"/>
         <source>Find &amp;Next</source>
         <translation>Gjej &amp;Pasuesin</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="115"/>
+        <location filename="../mainwindow.cpp" line="126"/>
         <source>Select &amp;All</source>
         <translation>Përzgjidhi &amp;Krejt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="121"/>
+        <location filename="../mainwindow.cpp" line="132"/>
         <source>Revert Selection</source>
         <translation>Prapaktheje Përzgjedhjen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="188"/>
+        <location filename="../mainwindow.cpp" line="200"/>
         <source>Program for displaying a quick system info report</source>
         <translation>Program për shfaqje të shpejtë të një raporti hollësish sistemi</translation>
     </message>
@@ -133,71 +178,84 @@
         <translation type="vanished">Licencë</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="193"/>
+        <location filename="../mainwindow.cpp" line="205"/>
         <source>%1 License</source>
-        <translation type="unfinished"></translation>
+        <translation>Licencë %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="280"/>
+        <location filename="../mainwindow.cpp" line="299"/>
         <source>Open folder</source>
         <translation>Hape dosjen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="282"/>
+        <location filename="../mainwindow.cpp" line="301"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="440"/>
+        <location filename="../mainwindow.cpp" line="468"/>
         <source>&amp;Save (×%1)...</source>
         <translation>&amp;Ruani (×%1)…</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="474"/>
+        <location filename="../mainwindow.cpp" line="503"/>
         <source>Find</source>
         <translation>Gjej</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="477"/>
+        <location filename="../mainwindow.cpp" line="506"/>
         <source>&amp;Find what:</source>
         <translation>&amp;Gjej çfarë:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="487"/>
+        <location filename="../mainwindow.cpp" line="516"/>
         <source>Match c&amp;ase</source>
         <translation>&amp;Siç është shkruar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="488"/>
+        <location filename="../mainwindow.cpp" line="517"/>
         <source>Match &amp;whole word only</source>
         <translation>Përkime vetëm me &amp;krejt fjalën</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="491"/>
+        <location filename="../mainwindow.cpp" line="520"/>
         <source>Direction</source>
         <translation>Kah</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="493"/>
+        <location filename="../mainwindow.cpp" line="522"/>
         <source>&amp;Up</source>
         <translation>&amp;Sipër</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="494"/>
+        <location filename="../mainwindow.cpp" line="523"/>
         <source>&amp;Down</source>
         <translation>&amp;Poshtë</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="536"/>
+        <location filename="../mainwindow.cpp" line="568"/>
+        <location filename="../mainwindow.cpp" line="573"/>
         <source>Cannot find &quot;%1&quot;</source>
         <translation>S’gjendet dot “%1”</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="710"/>
+        <source>No journal entries found at this admin and priority level</source>
+        <comment>no journal entries found at the options specified</comment>
+        <translation>S’u gjetën zëra ditari te ky përgjegjës dhe kjo shkallë përparësie</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="712"/>
+        <source>Error running journalctl command</source>
+        <comment>error report for journalctl command</comment>
+        <translation>Gabim në ekzekutimin e urdhrit journalctl</translation>
+    </message>
     <message>
         <source>Changelog</source>
         <translation type="vanished">Regjistër ndryshimesh</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="482"/>
+        <location filename="../mainwindow.cpp" line="511"/>
         <source>Cancel</source>
         <translation>Anuloje</translation>
     </message>
@@ -206,41 +264,37 @@
         <translation type="vanished">&amp;Mbylle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="223"/>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>Save System Information</source>
         <translation>Ruani Hollësi Sistemi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../mainwindow.cpp" line="298"/>
         <source>System information saved.</source>
         <translation>Hollësitë e sistemit u ruajtën.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../mainwindow.cpp" line="306"/>
         <source>Could not save system information.</source>
         <translation>S’u ruajtën dot hollësitë e sistemit.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="332"/>
+        <location filename="../mainwindow.cpp" line="351"/>
         <source>history</source>
         <translation>historik</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="354"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>%1 Help</source>
         <translation>Ndihmë për %1</translation>
     </message>
     <message>
-        <source>Quick System Info (gui)</source>
-        <translation type="vanished">Hollësi Sistemi Shpejt e Shpejt (gui)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="81"/>
+        <location filename="../mainwindow.cpp" line="82"/>
         <source>Copy for forum</source>
         <translation>Kopjoje për forum</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="86"/>
+        <location filename="../mainwindow.cpp" line="87"/>
         <source>Plain text copy</source>
         <translation>Kopje tekst i thjeshtë</translation>
     </message>
@@ -287,4 +341,4 @@
         <translation>&amp;Mbylle</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
